import subprocess
from pyngrok import ngrok


def hello(name: str = None) -> str:
    return f"""Hello {name if name else "World"}!"""


class Host:
    def __init__(self, port: int, requirements: list = None):
        super().__init__()
        self.port = port
        self._install_requirements(requirements)
        self._start_tunnel()

    def _install_requirements(self, requirements: list):
        subprocess.run(f"pip install --upgrade pip".split(), stdout=subprocess.PIPE)
        if not requirements:
            return
        for requirement in requirements:
            subprocess.run(f"pip install {requirement}".split(), stdout=subprocess.PIPE)

    def _start_tunnel(self):
        active_tunnels = ngrok.get_tunnels()
        for tunnel in active_tunnels:
            public_url = tunnel.public_url
            ngrok.disconnect(public_url)
        url = ngrok.connect(port=self.port, options={"bind_tls": True})
        print(f"Code Server can be accessed on: {url}")


class SimpleHttpServer(Host):
    def __init__(self, port: int, requirements: list = None):
        super().__init__(port, requirements)
        self._start_server()

    def _start_server(self):
        subprocess.run(
            f"python -m http.server {self.port}".split(), stdout=subprocess.PIPE
        )



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()


install_requires = ["pyngrok>=4"]
setup(
    author="Puneetha Pai",
    author_email="puneethapai29@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Host any python application in colab environment..",
    entry_points={
        "console_scripts": [
            "colab_host=colab_host.cli:main",
        ],
    },
    install_requires=install_requires,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="colab_host",
    name="colab_host",
    packages=find_packages(include=["colab_host", "colab_host.*"]),
    url="https://github.com/PuneethaPai/colab_host",
    version="0.1.3",
    zip_safe=False,
)



#!/usr/bin/env python
import pytest
from colab_host import colab_host


def test_sample_function():
    assert "Hello World!" == colab_host.hello()
    assert "Hello Puneeth!" == colab_host.hello("Puneeth")
